@@ -1,17 +1,17 @@
 ## Copyright (C) 2003 David Bateman
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with this program; If not, see <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} comms ('help')
@@ -97,11 +97,11 @@ function retval = comms(typ, tests)
     help ("comms");
   elseif (strcmp(typ,"info"))
     infopaths = ["."];
-    if (!isempty(split(path,":")))
-      infopaths =[infopaths; split(path,":")];
+    if (!isempty(char(strsplit (path, ":"))))
+      infopaths =[infopaths; char(strsplit (path, ":"))];
     endif
-    if (!isempty(split(DEFAULT_LOADPATH,":")))
-      infopaths =[infopaths; split(DEFAULT_LOADPATH,":")];
+    if (!isempty(char(strsplit (DEFAULT_LOADPATH, ":"))))
+      infopaths =[infopaths; char(strsplit (DEFAULT_LOADPATH, ":"))];
     endif
     for i=1:size(infopaths,1)
       infopath = deblank(infopaths(i,:));
@@ -109,7 +109,7 @@ function retval = comms(typ, tests)
       if (len)
         if (len > 1 && strcmp(infopath([len-1, len]),"//"))
           [status, showfile] = system(["find '", infopath(1:len-1), ...
-				       "' -name ", infofile]);
+                              "' -name ", infofile]);
         else
           [status, showfile] = system(["find '", infopath, "' -name ", ...
                               infofile, " -maxdepth 1"]);
